@@ -9,6 +9,7 @@ import arrow
 from pandas import DataFrame
 
 from freqtrade.configuration import PeriodicCache
+from freqtrade.constants import ListPairsWithTimeframes
 from freqtrade.exceptions import OperationalException
 from freqtrade.misc import plural
 from freqtrade.plugins.pairlist.IPairList import IPairList
@@ -71,8 +72,8 @@ class AgeFilter(IPairList):
         :param tickers: Tickers (from exchange.get_tickers()). May be cached.
         :return: new allowlist
         """
-        needed_pairs = [
-            (p, '1d') for p in pairlist
+        needed_pairs: ListPairsWithTimeframes = [
+            (p, '1d', self._config['candle_type_def']) for p in pairlist
             if p not in self._symbolsChecked and p not in self._symbolsCheckFailed]
         if not needed_pairs:
             # Remove pairs that have been removed before
@@ -88,7 +89,8 @@ class AgeFilter(IPairList):
         candles = self._exchange.refresh_latest_ohlcv(needed_pairs, since_ms=since_ms, cache=False)
         if self._enabled:
             for p in deepcopy(pairlist):
-                daily_candles = candles[(p, '1d')] if (p, '1d') in candles else None
+                daily_candles = candles[(p, '1d', self._config['candle_type_def'])] if (
+                    p, '1d', self._config['candle_type_def']) in candles else None
                 if not self._validate_pair_loc(p, daily_candles):
                     pairlist.remove(p)
         self.log_once(f"Validated {len(pairlist)} pairs.", logger.info)
