@@ -43,23 +43,23 @@ class Webhook(RPCHandler):
     def send_msg(self, msg: Dict[str, Any]) -> None:
         """ Send a message to telegram channel """
         try:
-
-            if msg['type'] == RPCMessageType.BUY:
-                valuedict = self._config['webhook'].get('webhookbuy', None)
-            elif msg['type'] == RPCMessageType.BUY_CANCEL:
-                valuedict = self._config['webhook'].get('webhookbuycancel', None)
-            elif msg['type'] == RPCMessageType.BUY_FILL:
-                valuedict = self._config['webhook'].get('webhookbuyfill', None)
-            elif msg['type'] == RPCMessageType.SELL:
-                valuedict = self._config['webhook'].get('webhooksell', None)
-            elif msg['type'] == RPCMessageType.SELL_FILL:
-                valuedict = self._config['webhook'].get('webhooksellfill', None)
-            elif msg['type'] == RPCMessageType.SELL_CANCEL:
-                valuedict = self._config['webhook'].get('webhooksellcancel', None)
+            whconfig = self._config['webhook']
+            if msg['type'] in [RPCMessageType.ENTRY]:
+                valuedict = whconfig.get('webhookentry', None)
+            elif msg['type'] in [RPCMessageType.ENTRY_CANCEL]:
+                valuedict = whconfig.get('webhookentrycancel', None)
+            elif msg['type'] in [RPCMessageType.ENTRY_FILL]:
+                valuedict = whconfig.get('webhookentryfill', None)
+            elif msg['type'] == RPCMessageType.EXIT:
+                valuedict = whconfig.get('webhookexit', None)
+            elif msg['type'] == RPCMessageType.EXIT_FILL:
+                valuedict = whconfig.get('webhookexitfill', None)
+            elif msg['type'] == RPCMessageType.EXIT_CANCEL:
+                valuedict = whconfig.get('webhookexitcancel', None)
             elif msg['type'] in (RPCMessageType.STATUS,
                                  RPCMessageType.STARTUP,
                                  RPCMessageType.WARNING):
-                valuedict = self._config['webhook'].get('webhookstatus', None)
+                valuedict = whconfig.get('webhookstatus', None)
             else:
                 raise NotImplementedError('Unknown message type: {}'.format(msg['type']))
             if not valuedict:
